@@ -2,6 +2,10 @@
 DEFAULT_URL = "https://hub.suprsend.com/"
 DEFAULT_UAT_URL = "https://collector-staging.suprsend.workers.dev/"
 
+# an Event should not have apparent body size of more than 100KB
+SINGLE_EVENT_MAX_APPARENT_SIZE_IN_BYTES = 100 * 1024  # 100 * 1024
+SINGLE_EVENT_MAX_APPARENT_SIZE_IN_BYTES_READABLE = "100KB"
+
 # a API call should not have apparent body size of more than 800KB
 BODY_MAX_APPARENT_SIZE_IN_BYTES = 800 * 1024  # 800 * 1024
 BODY_MAX_APPARENT_SIZE_IN_BYTES_READABLE = "800KB"
@@ -17,7 +21,7 @@ MAX_WORKFLOWS_IN_BULK_API = 100
 # max event-records in one bulk api call
 MAX_EVENTS_IN_BULK_API = 100
 
-ALLOW_ATTACHMENTS_IN_BULK_API = False
+ALLOW_ATTACHMENTS_IN_BULK_API = True
 ATTACHMENT_UPLOAD_ENABLED = False
 
 # -- single Identity event limit
